# civic_scraper.platforms.legistar package

## Submodules

## civic_scraper.platforms.legistar.scraper module

```{eval-rst}
.. automodule:: civic_scraper.platforms.legistar.scraper
   :members:
   :undoc-members:
   :show-inheritance:
```

## Module contents

```{eval-rst}
.. automodule:: civic_scraper.platforms.legistar
   :members:
   :undoc-members:
   :show-inheritance:
```
